#include <msp430g2001.h>
#define loc_reg4 0x0004
typedef unsigned int	word;
typedef unsigned char	byte;

void InitHost(void);
unsigned short readPinSettings(void);
void crystalWorkaround(word inputVal);
void resetHi(void);
void resetLo(void);
void scsHi(void);
void scsLo(void);
void ExitHost(void);
void usDelay(unsigned short microsecnds);
void Shift16(word shift_data);
void Spi_Write16(unsigned short address,unsigned short data);

//----------------------------------------------------------------------------
//   initialization function set pin modes and initial settings
//----------------------------------------------------------------------------
void InitHost(void)
{
	WDTCTL = WDTPW + WDTHOLD; // Disable watchdog timers
	
	//----------------------------------------------------------------------------
	//	MSP430 F2013	BUZZ		Function				Location
	//	P1.3 			RST			SPI Reset Toggle		BIT3
	//	P1.4 			SCS			SPI Enable (Select)		BIT4
	//	P1.5 			SCL			SPI Clock				BIT5
	//	P1.6 			SDA			SPI Data				BIT6
	//----------------------------------------------------------------------------
 
	P1DIR |= BIT3|BIT4|BIT5|BIT6; // Make P1.3, P1.4, P1.5, and P1.6 as outputs
	P1OUT &= ~(BIT6|BIT5|BIT3);	// bit6,bit5,bit3b0001 0000 P1 set low EXCEPT SCS Bit
	usDelay(50);
}

//----------------------------------------------------------------------------
// preset for reading pinSettings
//----------------------------------------------------------------------------
unsigned short readPinSettings(void)
{
	char value = 0;
	P1DIR &= ~(BIT1|BIT0); // set P1.0 and P1.1 to input b1111 1100
	value = (P1IN & 0x03);
	return value;
}

// reset pin to hi
void resetHi(void)
{
	P1OUT |= 0x08; // b0000 1000 P1.3 HI
	//usDelay(10);
}

// reset pin to lo
void resetLo(void)
{
	P1OUT &= ~(0x08); // b1111 0111
	//usDelay(10);
}

// scs delatch
void scsHi(void)
{
	P1OUT |= BIT4; // 0001 0000
	usDelay(50);
}

// scs latch
void scsLo(void)
{
	P1OUT &= ~(BIT4);
}

//
void ExitHost(void)
{
	scsHi();							// delatch scs
	//usDelay(10);
	P1DIR &= ~(BIT3|BIT5|BIT6);	// Make P1.3-6 highZ
	//usDelay(20);
	LPM3;								// low power mode 3
}
//----------------------------------------------------------------------------
//   Delay function (resolution is ~1 us)
//----------------------------------------------------------------------------
void usDelay(unsigned short microseconds)
{
	microseconds = microseconds * 8;
	do
	{
		_NOP();
	}
	while (--microseconds > 0);
}

//----------------------------------------------------------------------------
//	Function to shift data into device 16bit input data to shift
//----------------------------------------------------------------------------
void Shift16(word shift_data)
{
	char i;
	unsigned short MSB = 0x8000;
	unsigned short temp;
	
	usDelay(10); 
	
	for (i = 16; i >= 1; i--)
	{
		temp = shift_data & MSB;
		
	 	if(temp == 0) 
	 		P1OUT &= ~BIT6;				// data Stream (SDA) lo
		else
	 		P1OUT |= BIT6; 				// data Stream (SDA) hi
	 		
		shift_data <<= 1; 				// left shift data to get next msb
		usDelay(10);
		 
		P1OUT ^= BIT5; 					// SCL toggle High
		usDelay(10);  
		P1OUT ^= BIT5; 					// SCL toggle Low
	}
 }

//----------------------------------------------------------------------------
//	Function to SPI write 16bit address followed by data
//		note that address must be formatted via SPI protocol
//		as for SPI protocol - allows for 11bits of addressing
//----------------------------------------------------------------------------
void Spi_Write16(unsigned short address,unsigned short data)
{
	scsLo();
	usDelay(10);
	Shift16(address);
	usDelay(10);
	Shift16(data);	
	usDelay(10);
	scsHi();
}
